@@ -1,10 +1,10 @@
 use swc_ecma_visit::Fold;
 
-pub use self::exponentation::exponentation;
+pub use self::exponentiation::exponentiation;
 
-mod exponentation;
+mod exponentiation;
 
 #[tracing::instrument(level = "info", skip_all)]
 pub fn es2016() -> impl Fold {
-    exponentation()
+    exponentiation()
 }
