@@ -1,6 +1,7 @@
 use swc_atoms::JsWord;
 use swc_ecma_ast::*;
 use swc_ecma_visit::{noop_visit_type, Visit, VisitWith};
+use swc_trace_macro::swc_trace;
 
 pub(super) struct UsedNameCollector<'a> {
     pub used_names: &'a mut Vec<JsWord>,
@@ -13,6 +14,7 @@ macro_rules! noop {
     };
 }
 
+#[swc_trace]
 impl<'a> Visit for UsedNameCollector<'a> {
     noop_visit_type!();
 
